redi package
============

Subpackages
-----------

.. toctree::

    redi.utils

Submodules
----------

redi.batch module
-----------------

.. automodule:: redi.batch
    :members:
    :undoc-members:
    :show-inheritance:

redi.form module
----------------

.. automodule:: redi.form
    :members:
    :undoc-members:
    :show-inheritance:

redi.redi module
----------------

.. automodule:: redi.redi
    :members:
    :undoc-members:
    :show-inheritance:

redi.redi_lib module
--------------------

.. automodule:: redi.redi_lib
    :members:
    :undoc-members:
    :show-inheritance:

redi.report module
------------------

.. automodule:: redi.report
    :members:
    :undoc-members:
    :show-inheritance:

redi.upload module
------------------

.. automodule:: redi.upload
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: redi
    :members:
    :undoc-members:
    :show-inheritance:
